diff mbox

[v3] add tls symbols to abi checking

Message ID 20101001122212.1165f1a4@shotwell
State New
Headers show

Commit Message

Benjamin Kosnik Oct. 1, 2010, 5:22 p.m. UTC
As pointed out by Rainer, the current symbol-list checking for
libstdc++.so does not track exported TLS symbols. This is an oversight
that is corrected in the following patch. 

There should not be a difference in test results for this, as the
symbols were properly versioned from the beginning, yet ignored.
This just starts to pay attention to them.

tested x86_64/linux, make check-abi, verified that the two new symbols
show up as expected.

-benjamin
diff mbox

Patch

2010-10-01  Benjamin Kosnik  <bkoz@redhat.com>

	    * scripts/extract_symvers: Add support for tracking TLS symbols.
	    * testsuite/util/testsuite_abi.h (symbol::category): Add tls type.
	    * testsuite/util/testsuite_abi.cc: Set symbol type to tls when
	    appropriate, collect size info.


Index: scripts/extract_symvers
===================================================================
--- scripts/extract_symvers	(revision 164890)
+++ scripts/extract_symvers	(working copy)
@@ -92,7 +92,7 @@ 
     egrep -v ' (LOCAL|UND) ' |\
     awk '{ if ($4 == "FUNC" || $4 == "NOTYPE")
              printf "%s:%s\n", $4, $8;
-           else if ($4 == "OBJECT")
+           else if ($4 == "OBJECT" || $4 == "TLS")
              printf "%s:%s:%s\n", $4, $3, $8;
          }' | sort | uniq > $tmp 2>&1
 #          else printf "Huh?  What is %s?\n", $8;
Index: testsuite/util/testsuite_abi.h
===================================================================
--- testsuite/util/testsuite_abi.h	(revision 164890)
+++ testsuite/util/testsuite_abi.h	(working copy)
@@ -29,7 +29,7 @@ 
 // Encapsulates symbol characteristics.
 struct symbol
 {
-  enum category { function, object, uncategorized };
+  enum category { function, object, tls, uncategorized };
   enum designation { existing, added, subtracted, undesignated };
   enum version { none, compatible, incompatible, unversioned };
   enum compatibility
Index: testsuite/util/testsuite_abi.cc
===================================================================
--- testsuite/util/testsuite_abi.cc	(revision 164890)
+++ testsuite/util/testsuite_abi.cc	(working copy)
@@ -43,13 +43,15 @@ 
     type = symbol::function;
   else if (data.find("OBJECT") == 0)
     type = symbol::object;
+  else if (data.find("TLS") == 0)
+    type = symbol::tls;
 
   n = data.find_first_of(delim);
   if (n != npos)
     data.erase(data.begin(), data.begin() + n + 1);
 
-  // Iff object, get size info.
-  if (type == symbol::object)
+  // Iff object or TLS, get size info.
+  if (type == symbol::object || type == symbol::tls)
     {
       n = data.find_first_of(delim);
       if (n != npos)
@@ -130,6 +132,9 @@ 
     case object:
       type_string = "object";
       break;
+    case tls:
+      type_string = "tls";
+      break;
     case uncategorized:
       type_string = "uncategorized";
       break;
@@ -138,7 +143,7 @@ 
     }
   cout << "type: " << type_string << endl;
   
-  if (type == object)
+  if (type == object || type == tls)
     cout << "type size: " << size << endl;
 
   string status_string;